* SMPL-DA.ASM	10/9/96

* Simple Serial D/A board driver FOR CMD11 AND CMM11...
* Runs under the buffalo monitor for terminal I/O
*
* Operation - program configures SPI port (SS:KEYBOARD)
*	for master out mode and sends SS-DA board channel
*	data as configured in the SCAN_TABLEA,B,C,D. Channel output
*	can be monitored with a Oscope to see updates
*
* EXECUTION STEPS:
* 1. Load program under buffalo with LOAD T <CR command.
* 2. Start program with CALL 3000 <CR command.
* 3. Program will stair step D/A channel outputs.
* 4. To end program press any key on terminal keyboard. 

RAM	EQU	$2000	* DEFINE RAM START ADDRESS (VARIABLE LOCATION)
ROM	EQU	$3000	* DEFINE ROM START ADDRESS (PROGRAM LOCATION)

* 68HC11A1 Register definitions...

REGS         EQU        $1000		* Default reset address
PortA        EQU        REGS+$00
PortC        EQU        REGS+$03
PortB        EQU        REGS+$04
DDRC         EQU        REGS+$07
PortD        EQU        REGS+$08
DDRD         EQU        REGS+$09
PortE        EQU        REGS+$0A
CFORC        EQU        REGS+$0B
TCNT         EQU        REGS+$0E        * WORD
TIC1         EQU        REGS+$10        * WORD
TIC2         EQU        REGS+$12        * WORD
TIC3         EQU        REGS+$14        * WORD
TOC1         EQU        REGS+$16        * WORD
TOC2         EQU        REGS+$18        * WORD
TOC3         EQU        REGS+$1A        * WORD
TOC4         EQU        REGS+$1C        * WORD
TOC5         EQU        REGS+$1E        * WORD
TCTL1        EQU        REGS+$20
TCTL2        EQU        REGS+$21
TMSK1        EQU        REGS+$22
TFLG1        EQU        REGS+$23
TMSK2        EQU        REGS+$24
TFLG2        EQU        REGS+$25
PACTL        EQU        REGS+$26
PACNT        EQU        REGS+$27
SPCR	     EQU	REGS+$28
SPSR	     EQU	REGS+$29
SPDR	     EQU	REGS+$2A
BAUD         EQU        REGS+$2B
SCCR1        EQU        REGS+$2C
SCCR2        EQU        REGS+$2D
SCSR         EQU        REGS+$2E
SCDR         EQU        REGS+$2F
ADCTL        EQU        REGS+$30
OPTION       EQU        REGS+$39
PPROG        EQU        REGS+$3B
HPRIO        EQU        REGS+$3C
INIT         EQU        REGS+$3D
TEST         EQU        REGS+$3E
CONFIG       EQU        REGS+$3F

* Simple Serial driver definitions...

SS_port EQU     PortD   ; define simple serial port

* Simple Serial port bit definitions...

SS_DIN  equ     $04     * Data input bit 
SS_DOUT equ     $08     * Data output bit
SS_CLK  equ     $10     * Data clock bit
SS_CS1  equ     $20     * Chip select 1 out

* Simple Serial Analog to Digital Converter Select

CS_CS	equ	SS_CS1	* Define chip select


*....................................................................

* RAM DEFINTIONS

* BUFFALO Support Routine entry addresses...

UPCASE      EQU         $FFA0   convert to upper case
WCHEK       EQU         $FFA3   check for white space
DCHEK       EQU         $FFA6   check for delimeter
* INIT        EQU               $FFA9   initialize i/o device
INPUT       EQU         $FFAC   low level input routine
* OUTPUT      EQU               $FFAF   low level output routine
OUTLHLF     EQU         $FFB2   display top 4 bits as hex digit
OUTRHLF     EQU         $FFB5   display bottom 4 bits as hex digit
OUTA        EQU         $FFB8   output ascii character in A
OUT1BYT     EQU         $FFBB   display the hex value of byte at X
OUT1BSP     EQU         $FFBE   out1byt followed by space
OUT2BSP     EQU         $FFC1   display 2 hex bytes at x and a space
OUTCRLF     EQU         $FFC4   carriage return, line feed to terminal
OUTSTRG     EQU         $FFC7   display string at X (term with $04)
OUTSTRG0    EQU         $FFCA   outstrg with no initial carr ret
INCHAR      EQU         $FFCD   wait for and input a char from term
			       
EOT     EQU     $04     end of a text table

****************************************************************************

* PROGRAM START....

	ORG	ROM

* Simple Serial Driver initialization...

SET_SS
	CLR	SS_port		* Clear the port...
	LDAA	#$3A		* Configure port direction
	STAA	DDRD
	LDAA	#$52		* Configure SPI port
	STAA	SPCR		* 

* Main program loop, send Current sink data 

MAIN
	LDAA	#$01		* get current step
	JSR	UPDATE
	JSR	PAUSE
	LDAA	#$02		* get current step
	JSR	UPDATE
	JSR	PAUSE
	LDAA	#$04		* get current step
	JSR	UPDATE
	JSR	PAUSE
	LDAA	#$08		* get current step
	JSR	UPDATE
	JSR	PAUSE
	LDAA	#$10		* get current step
	JSR	UPDATE
	JSR	PAUSE
	LDAA	#$20		* get current step
	JSR	UPDATE
	JSR	PAUSE
	LDAA	#$40		* get current step
	JSR	UPDATE
	JSR	PAUSE
	LDAA	#$80		* get current step
	JSR	UPDATE
	JSR	PAUSE

* check for user input

	LDAA    SCSR		*
	ANDA    #$20            * TEST ANY USER INPUT
	BEQ     MAIN		* New row if not
	LDAA	SCDR		* CLEAR USER KEY
	RTS			* DONE

* Simple Serial Driver (SPI), source code...

SS_IO
	LDAB	SPSR		* CLEAR STATUS OF SPI
	STAA	SPDR		* SEND / RECEIVE BYTE
SS_IO_LP		
	LDAB	SPSR		* GET STATUS
	BPL	SS_IO_LP	* WAIT IF NO FLAG
	RTS

* Simple Serial source code...

UPDATE
	LDX	#SS_port	* set pointer to select port
	BSET	0,X CS_CS	* select 
	BSR	SS_IO		* send command
	BCLR	0,X CS_CS	* deselect and start next conversion
	RTS			* done

PAUSE
	LDX	#0
LOOP
	DEX
	BNE	LOOP
	RTS


	END
